@@ -20,7 +20,7 @@
 #include "k9dvdauthor.h"
 #include "k9dvdtitle.h"
 #include "k9dvdbackup.h"
-#include "kmessagebox.h"
+#include "tdemessagebox.h"
 #include "k9tools.h"
 
 #include <sys/types.h>
@@ -36,7 +36,7 @@
 #include <tqlabel.h>
 #include <tqprogressdialog.h>
 #include <signal.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqvaluelist.h>
 #include <kstandarddirs.h>
 #include <tqapplication.h>
@@ -444,10 +444,10 @@ void k9DVDAuthor::author() {
         TQString c("dvdauthor");
         proc=progress->getProcess();//  new TQProcess(c,0);
         *proc << c << "-x" <<  m_xml->name();  //locateLocal("tmp", "k9copy/k9author.xml");
-        connect( proc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)),
-                 this, TQT_SLOT(DVDAuthorStderr(KProcess *, char *, int )) );
-        connect( proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int )),
-                 this, TQT_SLOT(DVDAuthorStdout(KProcess *, char *, int)) );
+        connect( proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+                 this, TQT_SLOT(DVDAuthorStderr(TDEProcess *, char *, int )) );
+        connect( proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int )),
+                 this, TQT_SLOT(DVDAuthorStdout(TDEProcess *, char *, int)) );
         //    connect(progress, TQT_SIGNAL(cancelled()), this, TQT_SLOT(stopProcess()));
 
         m_copied=0;
@@ -488,7 +488,7 @@ void k9DVDAuthor::author() {
 
 
 /** No descriptions */
-void k9DVDAuthor::DVDAuthorStderr(KProcess *proc, char *buffer, int buflen ) {
+void k9DVDAuthor::DVDAuthorStderr(TDEProcess *proc, char *buffer, int buflen ) {
 
     //TQString m_stderr(proc->readStderr());
     TQString m_stderr=TQString::fromLatin1(buffer, buflen);
@@ -505,7 +505,7 @@ void k9DVDAuthor::DVDAuthorStderr(KProcess *proc, char *buffer, int buflen ) {
         //   m_copied+=totalBytes - m_lastPos;
         m_copied=totalBytes;
         m_lastPos=totalBytes;
-        //qDebug("%s", (TQString("copied : %1   totalSize : %2").arg(m_copied).arg(m_totalSize*512).ascii());
+        //tqDebug("%s", (TQString("copied : %1   totalSize : %2").arg(m_copied).arg(m_totalSize*512).ascii());
         m_percent=(float)m_copied / (float)(m_totalSize/DVD_VIDEO_LB_LEN );
 
 
@@ -526,7 +526,7 @@ void k9DVDAuthor::DVDAuthorStderr(KProcess *proc, char *buffer, int buflen ) {
     }
     /*    else {
             if (!m_stderr.startsWith("libdvdread") && m_stderr.startsWith("libdvdnav"))
-    	   qDebug("%s", m_stderr.ascii());
+    	   tqDebug("%s", m_stderr.ascii());
         }
     */
     int end;
@@ -557,7 +557,7 @@ void k9DVDAuthor::DVDAuthorStderr(KProcess *proc, char *buffer, int buflen ) {
 
 }
 
-void k9DVDAuthor::DVDAuthorStdout(KProcess *proc, char *buffer, int buflen) {
+void k9DVDAuthor::DVDAuthorStdout(TDEProcess *proc, char *buffer, int buflen) {
     TQString c=TQString::fromLatin1( buffer,buflen);
     //(proc->readStdout());
     int pos;
