@@ -870,7 +870,7 @@ void k9Ifo2::checkBuffer(TQString lib,uchar* _buffer) {
     if (memcmp(bufCopy,_buffer,bufCopySize)!=0) {
         TQString c;
         c="Buffer de sortie altéré: " +lib;
-        qDebug("%s", c.latin1());
+        tqDebug("%s", c.latin1());
     }
 }
 
